# PBShax

Missing tools for PBS clusters.


## `pbsparallel`

Like a shitty version of GNU parallel that uses `pbs_dsh` as a backend.

## `regionparallel`

Like `pbsparallel`, but with a helper function to iterate over genome regions

